Struct google_androiddeviceprovisioning1::api::CustomerMethods [−][src]
A builder providing access to all methods supported on customer resources.
It is not used directly, but through the AndroidProvisioningPartner hub.
Example
Instantiate a resource builder
extern crate hyper; extern crate hyper_rustls; extern crate yup_oauth2 as oauth2; extern crate google_androiddeviceprovisioning1 as androiddeviceprovisioning1; use std::default::Default; use oauth2; use androiddeviceprovisioning1::AndroidProvisioningPartner; let secret: oauth2::ApplicationSecret = Default::default(); let auth = yup_oauth2::InstalledFlowAuthenticator::builder( secret, yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect, ).build().await.unwrap(); let mut hub = AndroidProvisioningPartner::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()), auth); // Usually you wouldn't bind this to a variable, but keep calling *CallBuilders* // like `configurations_create(...)`, `configurations_delete(...)`, `configurations_get(...)`, `configurations_list(...)`, `configurations_patch(...)`, `devices_apply_configuration(...)`, `devices_get(...)`, `devices_list(...)`, `devices_remove_configuration(...)`, `devices_unclaim(...)`, `dpcs_list(...)` and `list(...)` // to build up your call. let rb = hub.customers();
Implementations
impl<'a> CustomerMethods<'a>[src]
pub fn configurations_create(
&self,
request: Configuration,
parent: &str
) -> CustomerConfigurationCreateCall<'a>[src]
&self,
request: Configuration,
parent: &str
) -> CustomerConfigurationCreateCall<'a>
Create a builder to help you perform the following task:
Creates a new configuration. Once created, a customer can apply the configuration to devices.
Arguments
request- No description provided.parent- Required. The customer that manages the configuration. An API resource name in the formatcustomers/[CUSTOMER_ID].
pub fn configurations_delete(
&self,
name: &str
) -> CustomerConfigurationDeleteCall<'a>[src]
&self,
name: &str
) -> CustomerConfigurationDeleteCall<'a>
Create a builder to help you perform the following task:
Deletes an unused configuration. The API call fails if the customer has devices with the configuration applied.
Arguments
name- Required. The configuration to delete. An API resource name in the formatcustomers/[CUSTOMER_ID]/configurations/[CONFIGURATION_ID]. If the configuration is applied to any devices, the API call fails.
pub fn configurations_get(&self, name: &str) -> CustomerConfigurationGetCall<'a>[src]
Create a builder to help you perform the following task:
Gets the details of a configuration.
Arguments
name- Required. The configuration to get. An API resource name in the formatcustomers/[CUSTOMER_ID]/configurations/[CONFIGURATION_ID].
pub fn configurations_list(
&self,
parent: &str
) -> CustomerConfigurationListCall<'a>[src]
&self,
parent: &str
) -> CustomerConfigurationListCall<'a>
Create a builder to help you perform the following task:
Lists a customer’s configurations.
Arguments
parent- Required. The customer that manages the listed configurations. An API resource name in the formatcustomers/[CUSTOMER_ID].
pub fn configurations_patch(
&self,
request: Configuration,
name: &str
) -> CustomerConfigurationPatchCall<'a>[src]
&self,
request: Configuration,
name: &str
) -> CustomerConfigurationPatchCall<'a>
Create a builder to help you perform the following task:
Updates a configuration’s field values.
Arguments
request- No description provided.name- Output only. The API resource name in the formatcustomers/[CUSTOMER_ID]/configurations/[CONFIGURATION_ID]. Assigned by the server.
pub fn devices_apply_configuration(
&self,
request: CustomerApplyConfigurationRequest,
parent: &str
) -> CustomerDeviceApplyConfigurationCall<'a>[src]
&self,
request: CustomerApplyConfigurationRequest,
parent: &str
) -> CustomerDeviceApplyConfigurationCall<'a>
Create a builder to help you perform the following task:
Applies a Configuration to the device to register the device for zero-touch enrollment. After applying a configuration to a device, the device automatically provisions itself on first boot, or next factory reset.
Arguments
request- No description provided.parent- Required. The customer managing the device. An API resource name in the formatcustomers/[CUSTOMER_ID].
pub fn devices_get(&self, name: &str) -> CustomerDeviceGetCall<'a>[src]
Create a builder to help you perform the following task:
Gets the details of a device.
Arguments
name- Required. The device to get. An API resource name in the formatcustomers/[CUSTOMER_ID]/devices/[DEVICE_ID].
pub fn devices_list(&self, parent: &str) -> CustomerDeviceListCall<'a>[src]
Create a builder to help you perform the following task:
Lists a customer’s devices.
Arguments
parent- Required. The customer managing the devices. An API resource name in the formatcustomers/[CUSTOMER_ID].
pub fn devices_remove_configuration(
&self,
request: CustomerRemoveConfigurationRequest,
parent: &str
) -> CustomerDeviceRemoveConfigurationCall<'a>[src]
&self,
request: CustomerRemoveConfigurationRequest,
parent: &str
) -> CustomerDeviceRemoveConfigurationCall<'a>
Create a builder to help you perform the following task:
Removes a configuration from device.
Arguments
request- No description provided.parent- Required. The customer managing the device in the formatcustomers/[CUSTOMER_ID].
pub fn devices_unclaim(
&self,
request: CustomerUnclaimDeviceRequest,
parent: &str
) -> CustomerDeviceUnclaimCall<'a>[src]
&self,
request: CustomerUnclaimDeviceRequest,
parent: &str
) -> CustomerDeviceUnclaimCall<'a>
Create a builder to help you perform the following task:
Unclaims a device from a customer and removes it from zero-touch enrollment. After removing a device, a customer must contact their reseller to register the device into zero-touch enrollment again.
Arguments
request- No description provided.parent- Required. The customer managing the device. An API resource name in the formatcustomers/[CUSTOMER_ID].
pub fn dpcs_list(&self, parent: &str) -> CustomerDpcListCall<'a>[src]
Create a builder to help you perform the following task:
Lists the DPCs (device policy controllers) that support zero-touch enrollment.
Arguments
parent- Required. The customer that can use the DPCs in configurations. An API resource name in the formatcustomers/[CUSTOMER_ID].
pub fn list(&self) -> CustomerListCall<'a>[src]
Create a builder to help you perform the following task:
Lists the user’s customer accounts.