Struct google_androiddeviceprovisioning1::api::CustomerRemoveConfigurationRequest [−][src]
Request message for customer to remove the configuration from device.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- devices remove configuration customers (request)
Fields
device: Option<DeviceReference>Required. The device to remove the configuration from.